==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/kvirc/ui/kvi_msgbox.cpp <==
//
//   File : kvi_msgbox.cpp
//   Creation date : Tue Jun 20 2000 12:49:41 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
#define __KVIRC__
#include "kvi_msgbox.h"

// FIXME: #warning "This should go into TAL as layer ...then maybe a wrapper in KviApp!"

#ifdef COMPILE_KDE_SUPPORT
	#include <kmessagebox.h>
#else
	#include <qmessagebox.h>
#endif //!COMPILE_WITH_KDE

#include "kvi_malloc.h"
#include "kvi_string.h"
#include "kvi_locale.h"

// FIXME: #warning "This could go into KviApp"

namespace KviMessageBox
{
	void warning(const QString &fmt,...)
	{
		kvi_va_list list;
		kvi_va_start_by_reference(list,fmt);
		QString s;
		KviQString::vsprintf(s,fmt,list);
		kvi_va_end(list);
#ifdef COMPILE_KDE_SUPPORT
		KMessageBox::error(0,s,"KVIrc");
#else
		QMessageBox::warning(0,"KVIrc",s);
#endif
	}
};



void kvi_warningBox(const char *fmt,...)
{
	//realloc 256 bytes
	char *buf=(char *)kvi_malloc(256);
	kvi_va_list list;
	kvi_va_start(list,fmt);
	//print...with max 256 chars
	int len=kvi_vsnprintf(buf,256,fmt,list);
	kvi_va_end(list);
	//check if we failed
	if(len < 0){
		//yes , failed....
		int ilen=256;
		do{ //we failed , so retry with 256 more chars
			ilen+=256;
			//realloc
			buf=(char *)kvi_realloc(buf,ilen);	
			//print...
			kvi_va_start(list,fmt);
			len=kvi_vsnprintf(buf,ilen,fmt,list);
			kvi_va_end(list);
		} while(len < 0);
	}
	//done...
	//now m_len is the length of the written string not including the terminator...
	//perfect! :)
	buf=(char *)kvi_realloc(buf,len+1);
#ifdef COMPILE_KDE_SUPPORT
	KMessageBox::error(0,QString(buf),"KVIrc");
#else
	QMessageBox::warning(0,"KVIrc",QString(buf));
#endif
	kvi_free(buf);
}

void kvi_infoBox(const char * caption,const char *fmt,...)
{
	//realloc 256 bytes
	char *buf=(char *)kvi_malloc(256);
	kvi_va_list list;
	kvi_va_start(list,fmt);
	//print...with max 256 chars
	int len=kvi_vsnprintf(buf,256,fmt,list);
	kvi_va_end(list);
	//check if we failed
	if(len < 0){
		//yes , failed....
		int ilen=256;
		do{ //we failed , so retry with 256 more chars
			ilen+=256;
			//realloc
			buf=(char *)kvi_realloc(buf,ilen);	
			//print...
			kvi_va_start(list,fmt);
			len=kvi_vsnprintf(buf,ilen,fmt,list);
			kvi_va_end(list);
		} while(len < 0);
	}
	//done...
	//now m_len is the length of the written string not including the terminator...
	//perfect! :)
	buf=(char *)kvi_realloc(buf,len+1);
#ifdef COMPILE_KDE_SUPPORT
	KMessageBox::information(0,QString(buf),QString(caption));
#else
	QMessageBox::information(0,QString(caption),QString(buf));
#endif
	kvi_free(buf);
}

bool kvi_yesNo(const char * caption,const char * fmt,...)
{	//realloc 256 bytes
	char *buf=(char *)kvi_malloc(256);
	kvi_va_list list;
	kvi_va_start(list,fmt);
	//print...with max 256 chars
	int len=kvi_vsnprintf(buf,256,fmt,list);
	kvi_va_end(list);
	//check if we failed
	if(len < 0){
		//yes , failed....
		int ilen=256;
		do{ //we failed , so retry with 256 more chars
			ilen+=256;
			//realloc
			buf=(char *)kvi_realloc(buf,ilen);	
			//print...
			kvi_va_start(list,fmt);
			len=kvi_vsnprintf(buf,ilen,fmt,list);
			kvi_va_end(list);
		} while(len < 0);
	}
	//done...
	//now m_len is the length of the written string not including the terminator...
	//perfect! :)
	buf=(char *)kvi_realloc(buf,len+1);
	bool bRet;
#ifdef COMPILE_KDE_SUPPORT
	bRet = (KMessageBox::questionYesNo(0,QString(buf),QString(caption)) == KMessageBox::Yes);
#else
	bRet = (QMessageBox::information(0,QString(caption),QString(buf),
			QMessageBox::Yes | QMessageBox::Default,
			QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes);
#endif
	kvi_free(buf);
	return bRet;
}

==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/kvirc/ui/kvi_msgbox.cpp <==
//
//   File : kvi_msgbox.cpp
//   Creation date : Tue Jun 20 2000 12:49:41 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
#define __KVIRC__
#include "kvi_msgbox.h"

// FIXME: #warning "This should go into TAL as layer ...then maybe a wrapper in KviApp!"

#ifdef COMPILE_KDE_SUPPORT
	#include <kmessagebox.h>
#else
	#include <qmessagebox.h>
#endif //!COMPILE_WITH_KDE

#include "kvi_malloc.h"
#include "kvi_string.h"
#include "kvi_locale.h"

// FIXME: #warning "This could go into KviApp"

namespace KviMessageBox
{
	void warning(const QString &fmt,...)
	{
		kvi_va_list list;
		kvi_va_start_by_reference(list,fmt);
		QString s;
		KviQString::vsprintf(s,fmt,list);
		kvi_va_end(list);
#ifdef COMPILE_KDE_SUPPORT
		KMessageBox::error(0,s,"KVIrc");
#else
		QMessageBox::warning(0,"KVIrc",s);
#endif
	}
	
	void infoBox(const QString &fmt,...)
	{
		kvi_va_list list;
		kvi_va_start_by_reference(list,fmt);
		QString s;
		KviQString::vsprintf(s,fmt,list);
		kvi_va_end(list);
#ifdef COMPILE_KDE_SUPPORT
		KMessageBox::information(0,s,"KVIrc");
#else
		QMessageBox::information(0,"KVIrc",s);
#endif
	}
	
	bool yesNo(const QString &caption,const QString &fmt,...)
	{
		kvi_va_list list;
		kvi_va_start_by_reference(list,fmt);
		QString s;
		KviQString::vsprintf(s,fmt,list);
		kvi_va_end(list);
		bool bRet;
#ifdef COMPILE_KDE_SUPPORT
		bRet = (KMessageBox::questionYesNo(0,s,caption) == KMessageBox::Yes);
#else
		bRet = (QMessageBox::information(0,caption,s,
				QMessageBox::Yes | QMessageBox::Default,
				QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes);
#endif
		return bRet;
	}
};
